% Interpolates quasiharmonic HMBI MP2/CBS + AMOEBA structure for phase I
% carbon dioxide at 296 K and an arbitrary pressure based on explicitly
% quasi-harmonic free energy optimizations between 1-20 GPa.
%
% To use: Simply specify the variable DesiredPressure below & run it.
%
% Based on: 
% "Theoretical Predictions Suggest Carbon Dioxide Phases III and
% VII are Identical." 
% Watit Sontising, Yonaton Heit, Jessica McKinley, and Gregory Beran.
% Department of Chemistry, University of California at Riverside.
% 2017.
% Corresponding Author Email: gregory.beran@ucr.edu
%
% Please cite this paper in all work derived from this script/data.
%
% Script is written for Matlab (commercial) / GNU Octave (open-source).
% Tested in Matlab 2016b and Octave 3.8.1

clear; % clear all variables from memory, just in case

% Specify the pressure(s) you wish the structure at here:
% Extrapolation outside the 1-20 GPa range is not recommended.
DesiredPressure = 7.46; % in GPa

% ----- shouldn't need to alter anything below this line -----

% Tabulate the explicitly computed QHA MP2/CBS structure data.
% Format: Pressure (GPa), lattice constant (Ang), fractional coordinate.
StructureData = [
	1.0,	5.504264,	0.122155;
	2.0,	5.373426,	0.125050;
	3.0,	5.285570,	0.127055;
	4.0,	5.218361,	0.128622;
	5.0,	5.164338,	0.129904;
	6.0,	5.118783,	0.130995;
	7.0,	5.079254,	0.131954;
	8.0,	5.044561,	0.132804;
	10.0,	4.985803,	0.134259;
	11.0,	4.960056,	0.134901;
	12.0,	4.936031,	0.135503;
	13.0,	4.913869,	0.136060;
	14.0,	4.893060,	0.136586;
	15.0,	4.873564,	0.137080;
	16.0,	4.855160,	0.137549;
	17.0,	4.837238,	0.138005;
	18.0,	4.820965,	0.138424;
	19.0,	4.805906,	0.138810;
	20.0,	4.790836,	0.139198];

% Perform the spline using Matlab/Octaves interp1 function. 
%   a = splined lattice constant
%   fx = splined fractional coordinate
a = interp1(StructureData(:,1),StructureData(:,2),DesiredPressure,'spline');
fx = interp1(StructureData(:,1),StructureData(:,3),DesiredPressure,'spline');


%%% Now print out the structure.
Nmolec_per_cell=4;
Natoms = 3*Nmolec_per_cell;

% Define fractional coordinates for the 4 CO2 molecules in phase I
% Ordered C,O,O, C,O,O, C,O,O, C,O,O
atom_names = ['C';'O';'O';'C';'O';'O';'C';'O';'O';'C';'O';'O';];
frac_coords = [
	0.0,	0.0,	0.0;
	fx,     fx,     fx;
	-fx,	-fx,	-fx;
	0.5,	0.0,	0.5;
	0.5-fx,	-fx,	0.5+fx;
	0.5+fx,	fx,     0.5-fx;
	0.0,	0.5,	0.5;
	-fx,	0.5+fx,	0.5-fx;
	fx,     0.5-fx,	0.5+fx;
	0.5,	0.5,	0;
	0.5+fx,	0.5-fx,	-fx;
	0.5-fx,	0.5+fx,	fx;];
	

fprintf('Splined Phase I Carbon Dioxide crystal structure at %.2f GPa\n',DesiredPressure);
fprintf('   Quasi-harmonic HMBI MP2/CBS + AMOEBA at 296K.\n')
fprintf('Lattice constants (Angstroms and degrees):\n   a\tb\tc\talpha\tbeta\tgamma\n');
fprintf('%.4f\t%.4f\t%.4f\t90.0\t90.0\t90.0\n\n',a,a,a);

% Compute volume (cubic cell) and molar volume
V=a^3;
Na= 6.0221367e23;
Ang_to_cm = 1.0e8;
molarV = V*6.0221367e23/(Ang_to_cm)^3/Nmolec_per_cell;
fprintf('Cell volume = %.3f Ang^3 = %.3f cm^3/mol\n\n',V,molarV);

fprintf('Fractional coordinates:\n');
for i=1:Natoms
    fprintf('%s %8.4f %8.4f %8.4f\n',atom_names(i),frac_coords(i,1),frac_coords(i,2),frac_coords(i,3));
end

fprintf('\nCartesian coordinates (Angstroms):\n');

for i=1:Natoms
   fprintf('%s %8.4f %8.4f %8.4f\n',atom_names(i),a*frac_coords(i,1),a*frac_coords(i,2),a*frac_coords(i,3));
end


