% Interpolates quasiharmonic HMBI MP2/CBS + AMOEBA structure for phase II
% carbon dioxide at 298 K and an arbitrary pressure based on explicitly
% quasi-harmonic free energy optimizations between 0-60 GPa.
%
% To use: Simply specify the variable DesiredPressure below & run it.
%
% Based on: 
% "Theoretical Predictions Suggest Carbon Dioxide Phases III and
% VII are Identical." 
% Watit Sontising, Yonaton Heit, Jessica McKinley, and Gregory Beran.
% Department of Chemistry, University of California at Riverside.
% 2017.
% Corresponding Author Email: gregory.beran@ucr.edu
%
% Please cite this paper in all work derived from this script/data.
%
% Script is written for Matlab (commercial) / GNU Octave (open-source).
% Tested in Matlab 2016b and Octave 3.8.1

clear; % clear all variables from memory, just in case

% Specify the pressure(s) you wish the structure at here:
% Extrapolation outside the 0-60 GPa range is not recommended.
DesiredPressure = 25.8; % in GPa

% ----- shouldn't need to alter anything below this line -----

% Tabulate the explicitly computed QHA MP2/CBS structure data.
% Format: Pressure (GPa), lattice constants a and c (Ang), 
%         fractional coordinates x & z.
StructureData = [
0.0,	4.52154,	4.64549,	0.18226,	0.50000;
2.0,	4.06636,    4.58487,	0.20246,	0.50000;
3.0,	3.98248,	4.54831,	0.20663,	0.50000;
5.0,	3.87100,	4.48610,	0.21241,	0.50000;
6.0,	3.83153,	4.45726,	0.21452,	0.50000;
7.0,	3.79809,	4.43021,	0.21632,	0.50000;
8.0,	3.76920,	4.40520,	0.21790,	0.50000;
9.0,	3.74360,	4.38332,	0.21931,	0.50000;
10.0,	3.72051,	4.36102,	0.22060,	0.50000;
11.0,	3.69879,	4.34295,	0.22182,	0.50000;
12.0,	3.68048,	4.32304,	0.22285,	0.50000;
13.0,	3.66279,	4.30439,	0.22385,	0.50000;
14.0,	3.64645,	4.28763,	0.22478,	0.50000;
20.0,	3.56688,	4.20302,	0.22936,	0.50000;
25.0,	3.52177,	4.13231,	0.23195,	0.50000;
30.0,	3.47693,	4.09426,	0.23462,	0.50000;
35.0,	3.44274,	4.04964,	0.23663,	0.50000;
40.0,	3.41262,	4.01115,	0.23840,	0.50000;
45.0,	3.38725,	3.97392,	0.23989,	0.50000;
50.0,	3.36433,	3.94048,	0.24123,	0.50000;
55.0,	3.34350,	3.91038,	0.24244,	0.50000;
60.0,	3.32512,	3.88139,	0.24351,	0.50000;];


% Perform the spline using Matlab/Octaves interp1 function. 
%   a,c = splined lattice constants
%   fx,fz = splined fractional coordinates
a = interp1(StructureData(:,1),StructureData(:,2),DesiredPressure,'spline');
b=a;
c = interp1(StructureData(:,1),StructureData(:,3),DesiredPressure,'spline');
fx = interp1(StructureData(:,1),StructureData(:,4),DesiredPressure,'spline');
fz = interp1(StructureData(:,1),StructureData(:,5),DesiredPressure,'spline');


%%% Now print out the structure.
Nmolec_per_cell=2;
Natoms = 3*Nmolec_per_cell;

% Define fractional coordinates for the 2 CO2 molecules in phase II
% Ordered C,O,O, C,O,O
atom_names = ['C';'O';'O';'C';'O';'O';];
frac_coords = [
	0.0,	0.0,	0.0;
	fx,     fx,     0.0;
	-fx,	-fx,	0.0;
	0.5,	0.5,	0.5;
	0.5-fx,	0.5+fx,	0.5;
	0.5+fx,	0.5-fx,	0.5;];
	

fprintf('Splined Phase II Carbon Dioxide crystal structure at %.2f GPa\n',DesiredPressure);
fprintf('   Quasi-harmonic HMBI MP2/CBS + AMOEBA at 298K.\n')
fprintf('Lattice constants (Angstroms and degrees):\n   a\tb\tc\talpha\tbeta\tgamma\n');
fprintf('%.4f\t%.4f\t%.4f\t90.0\t90.0\t90.0\n\n',a,b,c);

% Compute volume (orthorhombic cell) and molar volume
V=a*b*c;
Na= 6.0221367e23;
Ang_to_cm = 1.0e8;
molarV = V*6.0221367e23/Ang_to_cm^3/Nmolec_per_cell;
fprintf('Cell volume = %.3f Ang^3 = %.3f cm^3/mol\n\n',V,molarV);


fprintf('Fractional coordinates:\n');
for i=1:Natoms
    fprintf('%s %8.4f %8.4f %8.4f\n',atom_names(i),frac_coords(i,1),frac_coords(i,2),frac_coords(i,3));
end

fprintf('\nCartesian coordinates (Angstroms):\n');

for i=1:Natoms
   fprintf('%s %8.4f %8.4f %8.4f\n',atom_names(i),a*frac_coords(i,1),b*frac_coords(i,2),c*frac_coords(i,3));
end


