% Interpolates quasiharmonic HMBI MP2/CBS + AMOEBA structure for phase III/VII
% carbon dioxide at 298 K and an arbitrary pressure based on explicitly
% quasi-harmonic free energy optimizations between 0-60 GPa.  
%
% To use: Simply specify the variable DesiredPressure below & run it.
%
% Based on: 
% "Theoretical Predictions Suggest Carbon Dioxide Phases III and
% VII are Identical." 
% Watit Sontising, Yonaton Heit, Jessica McKinley, and Gregory Beran.
% Department of Chemistry, University of California at Riverside.
% 2017.
% Corresponding Author Email: gregory.beran@ucr.edu
%
% Please cite this paper in all work derived from this script/data.
%
% Script is written for Matlab (commercial) / GNU Octave (open-source).
% Tested in Matlab 2016b and Octave 3.8.1

clear; % clear all variables from memory, just in case

% Specify the pressure(s) you wish the structure at here:
% Extrapolation outside the 0-60 GPa range is not recommended.
DesiredPressure = 11.8; % in GPa

% ----- shouldn't need to alter anything below this line -----

% Tabulate the explicitly computed QHA MP2/CBS structure data.
% Format: Pressure (GPa), lattice constants a, b and c (Ang), 
%         fractional coordinates y & z.
StructureData = [
0.0,	5.74321,	5.08770,	6.66456,	0.18562,	0.10250;
1.0,	5.32010,	4.80306,	6.43482,	0.19503,	0.10759;
3.0,	5.04885,	4.58848,	6.27173,	0.20302,	0.11118;
4.0,	4.96916,	4.52949,	6.20992,	0.20555,	0.11225;
5.0,	4.90340,	4.47844,	6.16840,	0.20762,	0.11314;
6.0,	4.84894,	4.43814,	6.12463,	0.20943,	0.11388;
7.0,	4.80138,	4.40267,	6.08978,	0.21099,	0.11452;
8.0,	4.76540,	4.37904,	6.04284,	0.21238,	0.11504;
10.0,	4.69049,	4.32562,	5.99389,	0.21435,	0.11615;
12.0,	4.62891,	4.28144,	5.94860,	0.21689,	0.11695;
15.0,	4.54968,	4.22603,	5.89525,	0.21901,	0.11813;
20.0,	4.45250,	4.15432,	5.81435,	0.22242,	0.11959;
25.0,	4.37762,	4.09860,	5.74741,	0.22532,	0.12061;
30.0,	4.31203,	4.05409,	5.69242,	0.22762,	0.12149;
35.0,	4.25406,	4.01531,	5.64648,	0.22953,	0.12231;
40.0,	4.20411,	3.98216,	5.60481,	0.23124,	0.12297;
45.0	4.15986,	3.95255,	5.56765,	0.23278,	0.12356;
50.0,	4.12011,	3.92574,	5.53421,	0.23420,	0.12408;
55.0,	4.08414,	3.90132,	5.50351,	0.23550,	0.12454;
60.0,	4.05146,	3.87899,	5.47453,	0.23672,	0.12495;
];


% Perform the spline using Matlab/Octaves interp1 function. 
%   a,c = splined lattice constants
%   fx,fz = splined fractional coordinates
a = interp1(StructureData(:,1),StructureData(:,2),DesiredPressure,'spline');
b = interp1(StructureData(:,1),StructureData(:,3),DesiredPressure,'spline');
c = interp1(StructureData(:,1),StructureData(:,4),DesiredPressure,'spline');
fy = interp1(StructureData(:,1),StructureData(:,5),DesiredPressure,'spline');
fz = interp1(StructureData(:,1),StructureData(:,6),DesiredPressure,'spline');


%%% Now print out the structure.
Nmolec_per_cell=4;
Natoms = 3*Nmolec_per_cell;

% Define fractional coordinates for the 4 CO2 molecules in phase III/VII
% Ordered C,O,O, C,O,O, C,O,O, C,O,O
atom_names = ['C';'O';'O';'C';'O';'O';'C';'O';'O';'C';'O';'O';];
frac_coords = [
	0.0,	0.0,	0.0;
	0.0,     fy,    fz;
	0.0,	-fy,	-fz;
	0.0,	0.5,	0.5;
	0.0,	0.5-fy,	0.5+fz;
	0.0,	0.5+fy,	0.5-fz;
    0.5,	0.5,	0.0;
	0.5,    0.5+fy, fz;
	0.5,	0.5-fy,	-fz;
	0.5,	0.0,	0.5;
	0.5,	-fy,	0.5+fz;
	0.5,	fy, 	0.5-fz;];
	

fprintf('Splined Phase III/VII Carbon Dioxide crystal structure at %.2f GPa\n',DesiredPressure);
fprintf('   Quasi-harmonic HMBI MP2/CBS + AMOEBA at 298K.\n')
fprintf('Lattice constants (Angstroms and degrees):\n   a\tb\tc\talpha\tbeta\tgamma\n');
fprintf('%.4f\t%.4f\t%.4f\t90.0\t90.0\t90.0\n\n',a,b,c);

% Compute volume (orthorhombic cell) and molar volume
V=a*b*c;
Na= 6.0221367e23;
Ang_to_cm = 1.0e8;
molarV = V*6.0221367e23/(Ang_to_cm)^3/Nmolec_per_cell;
fprintf('Cell volume = %.3f Ang^3 = %.3f cm^3/mol\n\n',V,molarV);

fprintf('Fractional coordinates:\n');
for i=1:Natoms
    fprintf('%s %8.4f %8.4f %8.4f\n',atom_names(i),frac_coords(i,1),frac_coords(i,2),frac_coords(i,3));
end

fprintf('\nCartesian coordinates (Angstroms):\n');

for i=1:Natoms
   fprintf('%s %8.4f %8.4f %8.4f\n',atom_names(i),a*frac_coords(i,1),b*frac_coords(i,2),c*frac_coords(i,3));
end


